lighten method

Color lighten([
  1. double amount = .1
])

Lightens the color by blending it with white.

The amount parameter determines how much to lighten the color. A value of 0.0 returns the original color, and a value of 1.0 returns white. Defaults to 0.1 if not specified.

Implementation

Color lighten([double amount = .1]) =>
    Color.lerp(this, Colors.white, amount)!;