isFuture property
bool
get
isFuture
Determines if this is a future date, without considering time.
Implementation
bool get isFuture => isAfter(DateTime.now());
Determines if this is a future date, without considering time.
bool get isFuture => isAfter(DateTime.now());