isInNextYear property
bool
get
isInNextYear
Checks if this falls in the year after the current year.
Implementation
bool get isInNextYear => year == DateTime.now().year + 1;
Checks if this falls in the year after the current year.
bool get isInNextYear => year == DateTime.now().year + 1;