isInPreviousYear property
bool
get
isInPreviousYear
Checks if this falls in the year before the current year.
Implementation
bool get isInPreviousYear => year == DateTime.now().year - 1;
Checks if this falls in the year before the current year.
bool get isInPreviousYear => year == DateTime.now().year - 1;