isMonday property
bool
get
isMonday
Checks if this is a Monday according to ISO 8601.
Implementation
bool get isMonday => weekday == DateTime.monday;
Checks if this is a Monday according to ISO 8601.
bool get isMonday => weekday == DateTime.monday;