isPast property
bool
get
isPast
Determines if this is a date in the past, without considering time.
Implementation
bool get isPast => isBefore(DateTime.now());
Determines if this is a date in the past, without considering time.
bool get isPast => isBefore(DateTime.now());