isSaturday property
bool
get
isSaturday
Checks if this is a Saturday according to ISO 8601.
Implementation
bool get isSaturday => weekday == DateTime.saturday;
Checks if this is a Saturday according to ISO 8601.
bool get isSaturday => weekday == DateTime.saturday;