isSunday property
bool
get
isSunday
Checks if this is a Sunday according to ISO 8601.
Implementation
bool get isSunday => weekday == DateTime.sunday;
Checks if this is a Sunday according to ISO 8601.
bool get isSunday => weekday == DateTime.sunday;