isThursday property
bool
get
isThursday
Checks if this is a Thursday according to ISO 8601.
Implementation
bool get isThursday => weekday == DateTime.thursday;
Checks if this is a Thursday according to ISO 8601.
bool get isThursday => weekday == DateTime.thursday;