isTuesday property
bool
get
isTuesday
Checks if this is a Tuesday according to ISO 8601.
Implementation
bool get isTuesday => weekday == DateTime.tuesday;
Checks if this is a Tuesday according to ISO 8601.
bool get isTuesday => weekday == DateTime.tuesday;