isWednesday property
bool
get
isWednesday
Checks if this is a Wednesday according to ISO 8601.
Implementation
bool get isWednesday => weekday == DateTime.wednesday;
Checks if this is a Wednesday according to ISO 8601.
bool get isWednesday => weekday == DateTime.wednesday;