resetAllFields method

void resetAllFields()

Resets all the form fields to their initial values.

This method resets the state of all the form fields to their initial values, clearing any validation errors that might be displayed.

Implementation

void resetAllFields() {
  reset();
}