isDecimal property
bool
get
isDecimal
Checks if the string can be parsed as a decimal number.
Implementation
bool get isDecimal => toIntOrNull() != null;
Checks if the string can be parsed as a decimal number.
bool get isDecimal => toIntOrNull() != null;