isDouble property
bool
get
isDouble
Checks if the string can be parsed into a double.
Implementation
bool get isDouble => toDoubleOrNull() != null;
Checks if the string can be parsed into a double.
bool get isDouble => toDoubleOrNull() != null;