isOctal property
bool
get
isOctal
Checks if the string can be parsed as an octal number, which only contains characters 0-7.
Implementation
bool get isOctal => toIntOrNull(radix: 8) != null;
Checks if the string can be parsed as an octal number, which only contains characters 0-7.
bool get isOctal => toIntOrNull(radix: 8) != null;