toDoubleOrNull method
Tries to parse the string into a double, returning null if parsing fails.
Implementation
double? toDoubleOrNull() => double.tryParse(this);
Tries to parse the string into a double, returning null if parsing fails.
double? toDoubleOrNull() => double.tryParse(this);