toInt method
Converts the string to an int or returns null if conversion fails.
Implementation
int? toInt() {
return int.tryParse(this);
}
Converts the string to an int or returns null if conversion fails.
int? toInt() {
return int.tryParse(this);
}