DurationExtension extension

on

Properties

absoluteHours int

Available on Duration, provided by the DurationExtension extension

Returns the number of hours remaining after accounting for whole days.
no setter
absoluteMinutes int

Available on Duration, provided by the DurationExtension extension

Returns the number of minutes remaining after accounting for whole hours.
no setter
absoluteSeconds int

Available on Duration, provided by the DurationExtension extension

Returns the number of seconds remaining after accounting for whole minutes.
no setter
inYears int

Available on Duration, provided by the DurationExtension extension

Returns the number of whole years spanned by this Duration.
no setter
isInDays bool

Available on Duration, provided by the DurationExtension extension

Returns true if the Duration is equal to or longer than one day.
no setter
isInHours bool

Available on Duration, provided by the DurationExtension extension

Returns true if the Duration is equal to or longer than one hour but less than one day.
no setter
isInMillis bool

Available on Duration, provided by the DurationExtension extension

Returns true if the Duration is equal to or longer than one millisecond but less than one second.
no setter
isInMinutes bool

Available on Duration, provided by the DurationExtension extension

Returns true if the Duration is equal to or longer than one minute but less than one hour.
no setter
isInSeconds bool

Available on Duration, provided by the DurationExtension extension

Returns true if the Duration is equal to or longer than one second but less than one minute.
no setter
isInYears bool

Available on Duration, provided by the DurationExtension extension

Returns true if the Duration is equal to or longer than one year.
no setter