isInMillis property

bool get isInMillis

Returns true if the Duration is equal to or longer than one millisecond but less than one second.

Implementation

bool get isInMillis => inMilliseconds > 0 && !isInSeconds;