isInSeconds property

bool get isInSeconds

Returns true if the Duration is equal to or longer than one second but less than one minute.

Implementation

bool get isInSeconds => inSeconds > 0 && !isInMinutes;