darken method
Darkens the color by blending it with black.
The amount parameter determines how much to darken the color.
A value of 0.0 returns the original color, and a value of 1.0 returns black.
Defaults to 0.1 if not specified.
Implementation
Color darken([double amount = .1]) => Color.lerp(this, Colors.black, amount)!;